MathHelper class

Constructors

MathHelper()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

doSegmentsIntersect(Offset p1, Offset p2, Offset q1, Offset q2) → bool
Return true if two segments intersect
isBetween(num value, num from, num to) → bool
Return true if a value is between 2 other values
retrieveAngle(Offset a, Offset b) → double
Return an angle between 2 points