RecognizerText class abstract

Base object to represent a MlKit object

Implementers

Constructors

RecognizerText({required String text, required Trapezoid trapezoid})

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String
final
trapezoid → Trapezoid
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited