TextElement class

Represents a TextElement object of Ml Kit

Inheritance

Constructors

TextElement({required String text, required Trapezoid trapezoid})
TextElement.fromTextElement(TextElement textElement, Size imageSize)
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String
finalinherited
trapezoid → Trapezoid
finalinherited

Methods

copyWith({String? text, Trapezoid? trapezoid}) → TextElement
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override