TextLine class

Represents a TextLine object of Ml Kit

Inheritance

Constructors

TextLine({required List<TextElement> elements})
TextLine.fromTextLine(TextLine textLine, Size imageSize)
factory

Properties

elements → List<TextElement>
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String
finalinherited
trapezoid → Trapezoid
finalinherited

Methods

copyWith({List<TextElement>? elements}) → TextLine
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override