ScanMatchCounter class

Determines the visibility and validity of the results found by the different modules

  • For an element to be validated, the "_counter" must be equal to or greater than "validateCountCorrelation".
  • For an element to be visible, the counter must be at least 1. At each "frame", counter is updated.

Constructors

ScanMatchCounter({required ScanResult scanResult, required int validateCountCorrelation, required Color color})

Properties

color ↔ Color
The color to display during validation.
getter/setter pair
counter → int
no setter
hashCode → int
The hash code for this object.
no setterinherited
maxCorrelation → int
The maximum number before stopping to increment "counter". We avoid going too high to be able to quickly invalidate if the camera scans something else. ( Min : 5 , Max : validateCountCorrelation * 2 )
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scanResult ↔ ScanResult
Scan module result found in image
getter/setter pair
validateCountCorrelation ↔ int
Determine the number of times he must find the same result in the same place to validate it
getter/setter pair
validated ↔ bool
Determines if the result is validated
getter/setter pair
visible ↔ bool
Determines if the result is visible
getter/setter pair

Methods

actualColor() → Color
Return a color so the opacity is tied to the progress
downCounter() → void
Decrement "counter" if no result found
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
progressCorrelation() → double
Level of progress in % before validation of the result
toString() → String
A string representation of this object.
inherited
upCounter() → void
Increment "counter" if the result was found

Operators

operator ==(Object other) → bool
The equality operator.
inherited