ScanResult class

Each ScanModule should return a list of results. The results are the ScanResults. It contains the list of TextElements constituting the result.

Constructors

ScanResult({String? cleanedText, required List<TextElement> scannedElementList})

Properties

cleanedText → String
Return _cleanedText if it exists, or else real text
no setter
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scannedElementList ↔ List<TextElement>
List of all TextElements forming the result
getter/setter pair
text → String
Return real text
no setter
trapezoid → Trapezoid
Return the global trapezoid containing the list of TextElements
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override