ScanModule class abstract

Constructors

ScanModule({String? label, Color color = Colors.transparent, int validateCountCorrelation = 5, double distanceCorrelation = 0})

Properties

color ↔ Color
Module color (the color will be displayed in the final rendering)
getter/setter pair
distanceCorrelation ↔ double
The distance at which an object can be identified as the same (camera moves)
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
label ↔ String?
Module name (The name will be displayed in the final rendering)
getter/setter pair
matchedCounterList ↔ List<ScanMatchCounter>
The last list of results found by the module
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
started → bool
no setter
validateCountCorrelation ↔ int
The minimum number of times the same result must be found in the same place to validate ( Must be > 0 )
getter/setter pair

Methods

generateResult(List<TextBlock> textBlock, String text, Size imageSize) → Future<List<ScanMatchCounter>>
Launches the module result search then updates the list of old results
matchedResult(List<TextBlock> textBlock, String text) → Future<List<ScanResult>>
Method to be defined in each module to process the text found in the image and output a list of results
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
start() → void
Start the module
stop() → void
Stop the module
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited