OcrScanService class

Constructors

OcrScanService(List<ScanModule> scanModules)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scanModules ↔ List<ScanModule>
getter/setter pair
textRecognizer → TextRecognizer
MLKit text detection object
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
processImage(InputImage inputImage, Size imageSize, Image? background, Mode mode, List<ScanModule> scanModules, TextRecognizer? recognizer) → Future<OcrTextRecognizerResult?>
Launch the search for results from the image for all the modules started
startScanProcess(File file) → Future<OcrTextRecognizerResult?>
startScanWithOpenFile() → Future<OcrTextRecognizerResult?>
startScanWithPhoto() → Future<OcrTextRecognizerResult?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

actualMode → Mode
no setter